summaryrefslogtreecommitdiff
path: root/src/rc.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/rc.h')
-rw-r--r--src/rc.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/rc.h b/src/rc.h
index 681a550..2b392a4 100644
--- a/src/rc.h
+++ b/src/rc.h
@@ -143,10 +143,10 @@ bool rc_service_in_runlevel (const char *service, const char *runlevel);
* @return true if service state change was successful, otherwise false */
bool rc_service_mark (const char *service, rc_service_state_t state);
-/*! Lists the extra options a service has
- * @param service to load the options from
- * @return NULL terminated string list of options */
-char **rc_service_options (const char *service);
+/*! Lists the extra commands a service has
+ * @param service to load the commands from
+ * @return NULL terminated string list of commands */
+char **rc_service_extra_commands (const char *service);
/*! Check if the service is allowed to be hot/cold plugged
* @param service to check